==> tea_9.0.orig.tar.gz: tea-9.0/src/tea_gtk_utils.h <==
GtkWidget *mni_temp;

GtkWidget* tea_text_entry (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_color_selector (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_checkbox (GtkWidget *container, gchar *caption, gboolean *value);
GtkWidget* tea_spinbutton (GtkWidget *container, gchar *caption, gdouble value);
void logmemo_set_pos (GtkTextView *v, guint pos);
GtkWidget* tea_dir_selector (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_combo (GtkWidget *container, GList *strings, gchar *caption, gchar *value);
void widget_set_colors (GtkWidget *w, GdkColor *background, GdkColor *text, GdkColor *selection, GdkColor *sel_text);
gboolean dlg_question (gchar *caption, gchar *prompt, gchar *val);
void dlg_info (gchar *caption, gchar *prompt, gchar *val);
GtkWidget* tea_button_at_box (GtkWidget *container, gchar *caption, gpointer callback, gpointer user_data);
void cb_on_bt_close (GtkObject *object, GtkWidget *w); 
GtkWidget* find_menuitem (GtkContainer *widget, gchar *widget_name);
GtkFileFilter* tea_file_filter_with_patterns (gchar *name, gchar *pattern1, ...);
GtkFileFilter* find_ffilter_by_name (GtkFileChooser *chooser, gchar *name);
GtkWidget* daisho_add_del (gpointer *f1, gpointer f2);
GtkWidget* new_menu_item_with_udata (const gchar *label, GtkWidget *parent, gpointer f, gpointer data);
GtkWidget* new_menu_sep (GtkWidget *parent);
GtkWidget* new_menu_item (const gchar *label, GtkWidget *parent, gpointer f);
GtkWidget* new_menu_tof (GtkWidget *parent);
GtkWidget* new_menu_submenu (GtkWidget *parent);
void window_destroy (GtkWidget *windowname);
gboolean win_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w); 
GtkWidget* new_action_item (GtkActionGroup *ag, 
                            GtkWidget *parent, 
                            const gchar *name,
                            const gchar *label,
                            const gchar *tooltip,
                            const gchar *stock_id,
                            gpointer f);
void set_cursor_blink (gboolean value);
void fill_combo_with_glist (GtkComboBox *combo, GList *l);
GtkWidget* tea_gtk_toolbar_prepend_space (GtkToolbar *toolbar);
GtkWidget* tea_font_button (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_stock_button (const gchar *stock_id);

==> tea_11.0.orig.tar.gz: tea-11.0/src/tea_gtk_utils.h <==
GtkWidget *mni_temp;

GtkWidget* tea_text_entry (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_color_selector (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_checkbox (GtkWidget *container, gchar *caption, gboolean *value);
GtkWidget* tea_spinbutton (GtkWidget *container, gchar *caption, gdouble value);
void logmemo_set_pos (GtkTextView *v, guint pos);
GtkWidget* tea_dir_selector (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_combo (GtkWidget *container, GList *strings, gchar *caption, gchar *value);
void widget_set_colors (GtkWidget *w, GdkColor *background, GdkColor *text, GdkColor *selection, GdkColor *sel_text);
gboolean dlg_question (gchar *caption, gchar *prompt, gchar *val);
void dlg_info (gchar *caption, gchar *prompt, gchar *val);
GtkWidget* tea_button_at_box (GtkWidget *container, gchar *caption, gpointer callback, gpointer user_data);
void cb_on_bt_close (GtkObject *object, GtkWidget *w); 
GtkWidget* find_menuitem (GtkContainer *widget, gchar *widget_name);
GtkFileFilter* tea_file_filter_with_patterns (gchar *name, gchar *pattern1, ...);
GtkFileFilter* find_ffilter_by_name (GtkFileChooser *chooser, gchar *name);
GtkWidget* daisho_add_del (gpointer *f1, gpointer f2);
GtkWidget* new_menu_item_with_udata (const gchar *label, GtkWidget *parent, gpointer f, gpointer data);
GtkWidget* new_menu_sep (GtkWidget *parent);
GtkWidget* new_menu_item (const gchar *label, GtkWidget *parent, gpointer f);
GtkWidget* new_menu_tof (GtkWidget *parent);
GtkWidget* new_menu_submenu (GtkWidget *parent);
void window_destroy (GtkWidget *windowname);
gboolean win_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w); 
GtkWidget* new_action_item (GtkActionGroup *ag, 
                            GtkWidget *parent, 
                            const gchar *name,
                            const gchar *label,
                            const gchar *tooltip,
                            const gchar *stock_id,
                            gpointer f);
void set_cursor_blink (gboolean value);
void fill_combo_with_glist (GtkComboBox *combo, GList *l);
GtkWidget* tea_gtk_toolbar_prepend_space (GtkToolbar *toolbar);
GtkWidget* tea_font_button (GtkWidget *container, gchar *caption, gchar *value);
GtkWidget* tea_stock_button (const gchar *stock_id);
GtkWidget* tea_combo_combo (GtkWidget *container, GList *strings, gchar *caption, gint value);
gchar* dlg_question_char (gchar *prompt, gchar *defval);
gboolean dlg_key_handler (GtkWidget *widget, GdkEventKey *event, GtkWidget *w); 
void build_menu_from_ht (GHashTable *hash_table, gpointer menu, gpointer callback);
void build_menu_from_glist (GList *list, gpointer menu, gpointer callback);
void build_menu_wudata_from_glist (GList *list, gpointer menu, gpointer callback, gpointer udata);
void tea_widget_show (GtkWidget *w, gboolean visible);
GtkWidget* tea_color_selector_simple (GtkWidget *container, gchar *caption);
